==> haskell-with-utf8-1.1.0.0-15-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 with-utf8
version:              1.1.0.0
visibility:           public
id:                   with-utf8-1.1.0.0-55xjdOfx3Ww5X7vOZnJUqE
key:                  with-utf8-1.1.0.0-55xjdOfx3Ww5X7vOZnJUqE
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  1b4bbdee4798e8955450b456a0077774
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-9.2.8/site-local/with-utf8-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/with-utf8-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-utf8
hs-libraries:         HSwith-utf8-1.1.0.0-55xjdOfx3Ww5X7vOZnJUqE
depends:
    base-4.16.4.0 safe-exceptions-0.1.7.4-yGF8KbS5lSHGOL59YSfXx
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-with-utf8-1.1.0.0-50.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-with-utf8.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 with-utf8
version:              1.1.0.0
visibility:           public
id:                   with-utf8-1.1.0.0-D1mJioJ7xbyKYxOVUAMaGo
key:                  with-utf8-1.1.0.0-D1mJioJ7xbyKYxOVUAMaGo
license:              MPL-2.0
copyright:            2020 Serokell
maintainer:           Kirill Elagin <kirelagin@serokell.io>
author:               Kirill Elagin <kirelagin@serokell.io>
homepage:             https://github.com/serokell/haskell-with-utf8#readme
synopsis:             Get your IO right on the first try
description:
    This minimalistic library helps you navigate the world of text encodings
    avoiding @invalid argument (invalid byte sequence)@
    and @invalid argument (invalid character)@ in runtime.

    See <https://serokell.io/blog/haskell-with-utf8 this blog post> for why this
    library exists and what exactly it does.

    The two most important modules are:

    * "Main.Utf8"
    * "System.IO.Utf8"

category:             IO
abi:                  262986207f641cc71f4d146c53551ecb
exposed:              True
exposed-modules:
    Data.Text.IO.Utf8 Data.Text.Lazy.IO.Utf8 Main.Utf8 System.IO.Utf8
    System.IO.Utf8.Internal

hidden-modules:       Paths_with_utf8
import-dirs:          /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/with-utf8-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-with-utf8
hs-libraries:         HSwith-utf8-1.1.0.0-D1mJioJ7xbyKYxOVUAMaGo
depends:
    base-4.17.2.1 safe-exceptions-0.1.7.4-IOEkGTzCgP9nsdy3dwni1
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-with-utf8/html/with-utf8.haddock
haddock-html:         /usr/share/doc/haskell-with-utf8/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
